@@ -2,7 +2,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; File:         efs-mpe.el
-;; Release:      $efs release: 1.19 $
+;; Release:      $efs release: 1.20pre2 $
 ;; Version:      #Revision: 1.8 $
 ;; RCS:          
 ;; Description:  MPE (HP3000) support for efs.
@@ -14,7 +14,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;; This file is part of efs. See efs.el for copyright
-;;; (it's copylefted) and warrranty (there isn't one) information.
+;;; (it's copylefted) and warranty (there isn't one) information.
 
 ;;; Credits 
 ;;
@@ -123,7 +123,7 @@ This can take a very long time on large accounts")
 ;;; Internal Variables
 
 (defconst efs-mpe-version
-  (concat (substring "$efs release: 1.19 $" 14 -2)
+  (concat (substring "$efs release: 1.20pre2 $" 14 -2)
 	  "/"
 	  (substring "#Revision: 1.8 $" 11 -2)))
 
@@ -622,7 +622,7 @@ This can take a very long time on large accounts")
 
 (efs-defun efs-dired-fixup-listing mpe (file path &optional switches wildcard)
   ;; File (group) listings stay pretty much as they are group (account) and
-  ;; account (system) listings get realy hacked.
+  ;; account (system) listings get really hacked.
   (efs-save-match-data
     (goto-char (point-max))
     (string-match 
